pub enum OutgoingInterface {
Ipv4Addr(Ipv4Addr),
Ipv6Addr(Ipv6Addr),
Ipv6Index(u32),
}Expand description
Explicit outgoing multicast interface selection.
Variants
Ipv4Addr(Ipv4Addr)
Select the IPv4 multicast egress interface by local IPv4 address.
Ipv6Addr(Ipv6Addr)
Select the IPv6 multicast egress interface by local IPv6 address.
On the IPv6 send path this also provides the exact local address to bind when no explicit source address was configured.
Ipv6Index(u32)
Select the IPv6 multicast egress interface by interface index.