MctxError

Enum MctxError 

pub enum MctxError {
Show 16 variants InvalidDestinationPort, InvalidMulticastGroup, InvalidSourcePort, InvalidSourceAddress, InvalidInterfaceAddress, DuplicatePublication, PublicationNotFound, SocketCreateFailed(Error), SocketOptionFailed(Error), SocketBindFailed(Error), SocketConnectFailed(Error), SocketLocalAddrFailed(Error), ExistingSocketMustBeIpv4, ExistingSocketPortMismatch { expected: u16, actual: u16, }, ExistingSocketAddressMismatch { expected: Ipv4Addr, actual: Ipv4Addr, }, SendFailed(Error),
}
Errors returned by the multicast sender core.

Variants



InvalidDestinationPort

The configured destination port is invalid.



InvalidMulticastGroup

The configured group address is not a valid multicast IPv4 address.



InvalidSourcePort

The configured source port is invalid.



InvalidSourceAddress

The configured source IPv4 address is invalid.



InvalidInterfaceAddress

The configured multicast interface address is invalid.



DuplicatePublication

A publication with the same configuration already exists.



PublicationNotFound

No publication with the requested ID exists.



SocketCreateFailed(Error)

Creating the UDP socket failed.



SocketOptionFailed(Error)

Setting a socket option failed.



SocketBindFailed(Error)

Binding the UDP socket failed.



SocketConnectFailed(Error)

Connecting the UDP socket failed.



SocketLocalAddrFailed(Error)

Reading the local address from a socket failed.



ExistingSocketMustBeIpv4

The provided existing socket does not match the current IPv4-only send model.



ExistingSocketPortMismatch

The provided existing socket is bound to a different UDP port than requested.

Fields

expected: u16
actual: u16


ExistingSocketAddressMismatch

The provided existing socket is bound to a different local IPv4 address than requested.

Fields

expected: Ipv4Addr
actual: Ipv4Addr


SendFailed(Error)

Sending a packet failed.