pub struct RawContext { /* private fields */ }Expand description
Owns and manages the set of active raw multicast publications.
Implementations
Sourceimpl RawContext
impl RawContext
Sourcepub fn publication_count(&self) -> usize
pub fn publication_count(&self) -> usize
Returns the number of active raw publications.
Sourcepub fn contains_publication(&self, id: RawPublicationId) -> bool
pub fn contains_publication(&self, id: RawPublicationId) -> bool
Returns true if a raw publication with the given ID exists.
Sourcepub fn get_publication(&self, id: RawPublicationId) -> Option<&RawPublication>
pub fn get_publication(&self, id: RawPublicationId) -> Option<&RawPublication>
Returns the raw publication with the given ID, if present.
Sourcepub fn get_publication_mut(
&mut self,
id: RawPublicationId,
) -> Option<&mut RawPublication>
pub fn get_publication_mut( &mut self, id: RawPublicationId, ) -> Option<&mut RawPublication>
Returns the raw publication mutably with the given ID, if present.
Sourcepub fn add_publication(
&mut self,
config: RawPublicationConfig,
) -> Result<RawPublicationId, MctxError>
pub fn add_publication( &mut self, config: RawPublicationConfig, ) -> Result<RawPublicationId, MctxError>
Adds a new raw publication to the context.
Sourcepub fn remove_publication(&mut self, id: RawPublicationId) -> bool
pub fn remove_publication(&mut self, id: RawPublicationId) -> bool
Removes one raw publication and drops its socket.
Sourcepub fn take_publication(
&mut self,
id: RawPublicationId,
) -> Option<RawPublication>
pub fn take_publication( &mut self, id: RawPublicationId, ) -> Option<RawPublication>
Extracts one raw publication from the context.
Sourcepub fn send_raw(
&self,
id: RawPublicationId,
ip_datagram: &[u8],
) -> Result<RawSendReport, MctxError>
pub fn send_raw( &self, id: RawPublicationId, ip_datagram: &[u8], ) -> Result<RawSendReport, MctxError>
Sends one full IP datagram through the selected raw publication.